@@ -1,7 +1,8 @@
 surveydetails <- function(
     survey,
     api_key = getOption('sm_api_key'),
-    oauth_token = getOption('sm_oauth_token')
+    oauth_token = getOption('sm_oauth_token'),
+    ...
 ){
     if(inherits(survey, 'sm_survey'))
         survey <- survey$survey_id
@@ -17,12 +18,31 @@ surveydetails <- function(
     h <- add_headers(Authorization=token,
                      'Content-Type'='application/json')
     b <- toJSON(list(survey_id = survey), auto_unbox = TRUE)
-    out <- POST(u, config = h, body = b)
+    out <- POST(u, config = h, ..., body = b)
     stop_for_status(out)
     content <- content(out, as='parsed')
-    if(content$status==3) {
+    if(content$status != 0) {
         warning("An error occurred: ",content$errmsg)
         return(content)
     } else
         structure(content$data, class='sm_survey')
 }
+
+surveyquestions <- function(
+    survey,
+    details,
+    api_key = getOption('sm_api_key'),
+    oauth_token = getOption('sm_oauth_token'),
+    ...
+){
+    if (!missing(survey)) {
+        d <- surveydetails(survey, api_key = api_key, oauth_token = oauth_token, ...)
+    } else {
+        d <- details
+    }
+    questions <- unlist(unlist(lapply(d$pages, `[`, "questions"), recursive = FALSE), recursive = FALSE)
+    n <- unname(unlist(lapply(questions, `[`, "question_id")))
+    w <- unname(unlist(lapply(questions, `[`, "heading")))
+    structure(w, names = n, class = c("character", "sm_surveyquestions"))
+}
+
